# -*- coding: utf-8 -*-
from os.path import dirname,abspath,isdir,join
from os import listdir
import imp
from pysite.compat import PORTABLE_BYTES,PORTABLE_STRING

translation_maps = {
	'no': ['no','nb','nn'],
	'dk': ['dk','da'],
	'se': ['se','sv'],
	'en': ['en','us','gb'],
	'nb': ['nb','no','nn'],
	'nn': ['nn','no','nb'],
	'sv': ['sv','se'],
	'da': ['da','dk'],
	'uk': ['uk','en','us'],
	'us': ['us','en','uk']
}

class Localization(object):
	
	def __init__(self,translations_dir):
		self.translations_dir = translations_dir
		self.translations = {}
		self.languages = []
	
	def update_translation_dict(self,lang,context):
		lang_dict = self.translations.get(lang)
		if type(lang_dict)==dict:
			context_dict = lang_dict.get(context)
			if type(context_dict)==dict:
				return context_dict
		else:
			self.translations[lang] = {}
			
		try:
			transmod = imp.load_source(context, join(self.translations_dir,lang,'%s.py' % context))
			self.translations[lang][context] = transmod.translations
		except Exception as e:
			self.translations[lang][context] = {}
		return self.translations[lang][context]

	def _tr(self,trans_item,source,disambiguation=None):
		dest_source = PORTABLE_STRING('#') + source
		if disambiguation and type(trans_item)==dict:
			disambiguation_source = trans_item.get(disambiguation)
			if disambiguation_source:
				dest_source = disambiguation_source
			elif len(trans_item):
				dest_source = next (iter (trans_item.values()))
		elif type(trans_item)==dict and len(trans_item):
			dest_source = next (iter (trans_item.values()))
		elif trans_item:
			dest_source = trans_item
		return dest_source

	def tr(self,lang,context,source=None,disambiguation=None):
		trans_dict = self.update_translation_dict(lang,context)
		if type(source)==PORTABLE_BYTES:
			# default utf-8 if incoming is PORTABLE_BYTES
			# FIXME: use chardet
			source = PORTABLE_STRING(source,'utf-8')
		if source:
			trans_item = trans_dict.get(source)
			return self._tr(trans_item,source,disambiguation)
		else:
			ret_dict = {}
			for source,trans_item in trans_dict.items():
				ret_dict[source] = self._tr(trans_item,source,disambiguation)
			return ret_dict


	def lang_support(self,lang=None):
		global translation_maps
		if not len(self.languages):
			fs_elements = listdir(self.translations_dir)
			for fs_elem in fs_elements:
				if isdir(join(self.translations_dir,fs_elem)):
					self.languages += [fs_elem]
		if lang in translation_maps:
			for l in translation_maps[lang]:
				if self.languages.count(l):
					return l
		return self.languages

glob_loc = {}
def localization(translations_dir):
	global glob_loc
	if translations_dir not in glob_loc:
		glob_loc[translations_dir] = Localization(translations_dir)
	return glob_loc[translations_dir]



#!/usr/bin/python
# -*- coding: utf-8 -*-
from jinja2 import Environment
from jinja2.nodes import Getitem,Getattr,Const,Name,Call
import os,re,pprint
import imp,ast,sys
import xml.dom.minidom as minidom
from os.path import relpath,dirname
from pysite.compat import PORTABLE_STRING

if sys.version_info[0]==2:
	arg_name_attr = 'id'
elif sys.version_info[0]>=3:
	arg_name_attr = 'arg'

global_transdict = {}
global_first_located = {}

def update_transdict(context,source,filename,lineno,comment=''):
	global global_transdict
	if context not in global_transdict:
		global_transdict[context] = {}
		global_first_located[context] = {}
	if source not in global_transdict[context]:
		global_transdict[context][source] = []
		global_first_located[context][source] = {}
	if comment not in global_transdict[context][source]:
		global_transdict[context][source] += [comment]
		global_first_located[context][source][comment] = [filename,PORTABLE_STRING(lineno)]

def parse_subhandler(context):
	translate_args = ['source','context','comment','lang']
	fname = PORTABLE_STRING('subhandlers/%s.py' % context)
	a = ast.parse(open(fname).read())
	encoding = 'utf-8'
	for obj in a.body:
		if isinstance(obj,ast.FunctionDef) and obj.name=='init':
			translator_id = getattr(obj.args.args[3],arg_name_attr)
			for n in ast.walk(obj):
				if isinstance(n,ast.Call) and isinstance(n.func,ast.Name) and n.func.id==translator_id:
					acnt = 0
					args = {'source':None,'context':context,'comment':PORTABLE_STRING('')}
					for arg in n.args:
						if isinstance(arg,ast.Str):
							args[translate_args[acnt]] = arg.s if type(arg.s)==PORTABLE_STRING else PORTABLE_STRING(arg.s,encoding)
						acnt+=1
					for kwarg in n.keywords:
						args[kwarg.arg] = kwarg.value.s if type(kwarg.value.s)==PORTABLE_STRING else PORTABLE_STRING(kwarg.value.s,encoding)
					update_transdict(args['context'],args['source'],fname,n.lineno,args['comment'])

def parse_jinja_template(context):
	translate_args = ['source','context','comment','lang']
	e = Environment()
	fname = PORTABLE_STRING('templates/%s.jinja' % context)
	stream = open(fname,'rb')
	t = e.parse(PORTABLE_STRING(stream.read(),'utf-8'))
	for it in t.find_all(Getitem):
		if isinstance(it.node,Name) and it.node.name=='tr' and isinstance(it.arg,Const):
			update_transdict(context,it.arg.value,fname,it.node.lineno)
	for it in t.find_all(Getattr):
		if isinstance(it.node,Name) and it.node.name=='tr':
			update_transdict(context,it.attr,fname,it.node.lineno)
	for it in t.find_all(Getitem):
		if isinstance(it.node,Name) and it.node.name=='tr_common' and isinstance(it.arg,Const):
			update_transdict('common',it.arg.value,fname,it.node.lineno)
	for it in t.find_all(Getattr):
		if isinstance(it.node,Name) and it.node.name=='tr_common':
			update_transdict('common',it.attr,fname,it.node.lineno)
	for it in t.find_all(Call):
		if isinstance(it.node,Name) and it.node.name=='translate':
			acnt = 0
			args = {'source':None,'context':context,'comment':''}
			for arg in it.args:
				if isinstance(arg,Const):
					args[translate_args[acnt]] = arg.value
				acnt+=1
			for kwarg in it.kwargs:
				args[kwarg.key] = kwarg.value.value
			update_transdict(args['context'],args['source'],fname,it.node.lineno,args['comment'])

flist = os.listdir('templates')
for fname in flist:
	m = re.match('^([^\.]+)\.jinja$',fname)
	if m:
		parse_jinja_template(m.groups()[0])

flist = os.listdir('subhandlers')
for fname in flist:
	m = re.match('^([^\.]+)\.py$',fname)
	if m:
		parse_subhandler(m.groups()[0])


def parse_ts(ts_fname):
	doc = minidom.parse(open(ts_fname))
	tr_dict = {}
	for ctx_elem in doc.getElementsByTagName('context'):
		name = ctx_elem.getElementsByTagName('name')[0]
		context = name.childNodes[0].data
		tr_dict[context] = {}
		for msg_elem in ctx_elem.getElementsByTagName('message'):
			src_elem = msg_elem.getElementsByTagName('source')
			if not len(src_elem):
				continue
			source = src_elem[0].childNodes[0].data
			if source not in tr_dict[context]:
				tr_dict[context][source] = {}

			comment = PORTABLE_STRING('')
			c_elem = msg_elem.getElementsByTagName('comment')
			if len(c_elem):
				comment = c_elem[0].childNodes[0].data
			if comment not in tr_dict[context][source]:
				tr_dict[context][source][comment] = {}
			
			translation = None
			tr_elem = msg_elem.getElementsByTagName('translation')
			if len(tr_elem):
				if len(tr_elem[0].childNodes):
					translation = tr_elem[0].childNodes[0].data
				tr_dict[context][source][comment]['type'] = None
				if tr_elem[0].hasAttribute('type'):
					tr_dict[context][source][comment]['type'] = tr_elem[0].getAttribute('type')
			tr_dict[context][source][comment]['translation'] = translation
			
			filename = None
			line = None
			l_elem = msg_elem.getElementsByTagName('location')
			if len(l_elem):
				filename = l_elem[0].getAttribute('filename')
				line = l_elem[0].getAttribute('line')
			tr_dict[context][source][comment]['filename'] = filename
			tr_dict[context][source][comment]['line'] = line
	return tr_dict

def rebuild_ts(ts_dict,language,filename_pathprefix):
	global global_transdict,global_first_located
	doc = minidom.Document()
	ts = doc.createElement('TS')
	ts.setAttribute('version','2.0')
	ts.setAttribute('language',language)
	print([type(language),language])
	doc.appendChild(ts)
	for context,sources in global_transdict.items():
		context_elem = doc.createElement('context')
		name = doc.createElement('name')
		name.appendChild(doc.createTextNode(context))
		context_elem.appendChild(name)
		ts.appendChild(context_elem)
		for k,v in sources.items():
			for comment in v:
				msg_elem = doc.createElement('message')
				loc_elem = doc.createElement('location')
				loc_elem.setAttribute('filename',os.path.join(filename_pathprefix,global_first_located[context][k][comment][0]))
				loc_elem.setAttribute('line',global_first_located[context][k][comment][1])
				msg_elem.appendChild(loc_elem)
				src_elem = doc.createElement('source')
				print([type(k),k])
				src_elem.appendChild(doc.createTextNode(k))
				msg_elem.appendChild(src_elem)
				if comment:
					commen_elem = doc.createElement('comment')
					commen_elem.appendChild(doc.createTextNode(comment))
					msg_elem.appendChild(commen_elem)
				tr_elem = doc.createElement('translation')
				try:
					tr = ts_dict[context][k][comment]['translation']
					tr_elem.appendChild(doc.createTextNode(tr))
					if ts_dict[context][k][comment]['type']:
						tr_elem.setAttribute('type',ts_dict[context][k][comment]['type'])
				except:
					tr_elem.setAttribute('type','unfinished')
				msg_elem.appendChild(tr_elem)
				context_elem.appendChild(msg_elem)
	for context,sources in ts_dict.items():
		ctx_elem = None
		for it_ctx in doc.getElementsByTagName('context'):
			name_elem = it_ctx.getElementsByTagName('name')
			if name_elem[0].childNodes[0].data == context:
				ctx_elem = it_ctx
				break
		if not ctx_elem:
			ctx_elem = doc.createElement('context')
			name = doc.createElement('name')
			name.appendChild(doc.createTextNode(context))
			ctx_elem.appendChild(name)
			ts.appendChild(ctx_elem)

		for source,comments in sources.items():
			for comment,trinfo in comments.items():
				if trinfo['translation']:
					if context not in global_transdict or source not in global_transdict[context] or not global_transdict[context][source].count(comment):
						msg_elem = doc.createElement('message')
						src_elem = doc.createElement('source')
						src_elem.appendChild(doc.createTextNode(source))
						msg_elem.appendChild(src_elem)
						if comment:
							commen_elem = doc.createElement('comment')
							commen_elem.appendChild(doc.createTextNode(comment))
							msg_elem.appendChild(commen_elem)
						tr_elem = doc.createElement('translation')
						tr_elem.appendChild(doc.createTextNode(trinfo['translation']))
						tr_elem.setAttribute('type','obsolete')
						msg_elem.appendChild(tr_elem)
						ctx_elem.appendChild(msg_elem)
	return doc.toxml(encoding='utf-8')

def lupdate(ts_fname,language):
	ts_dict = {}
	filename_pathprefix = relpath('.',dirname(ts_fname))
	if not os.path.exists(dirname(ts_fname)):
		os.makedirs(dirname(ts_fname))
		f = open("%s/__init__.py" % dirname(ts_fname),'w')
		f.close()
	if os.path.exists(ts_fname):
		ts_dict = parse_ts(ts_fname)
	res=rebuild_ts(ts_dict,language,filename_pathprefix)
	open(ts_fname,'wb').write(res)

if __name__=='__main__':
	if len(sys.argv)<3:
		sys.stderr.write("usage: %s <ts-file> <lang-code>\n" % sys.argv[0])
		sys.stderr.write("Example: %s admin_da.ts da_DK\n" % sys.argv[0])
		sys.exit(1)
	lupdate(sys.argv[1],sys.argv[2])



# -*- coding: utf-8 -*-
import re,sys
from pysite.compat import PORTABLE_STRING,PORTABLE_BYTES

if sys.version_info[0]==2:
	from urllib2 import unquote
elif sys.version_info[0]>=3:
	from urllib.parse import unquote

class HTTPRequestData(object):
	def __init__(self,post_values,query_string,cookies):
		if type(post_values)==PORTABLE_BYTES:
			post_values = PORTABLE_STRING(post_values,'utf-8')
		if type(query_string)==PORTABLE_BYTES:
			query_string = PORTABLE_STRING(query_string,'utf-8')
		if type(cookies)==PORTABLE_BYTES:
			cookies = PORTABLE_STRING(cookies,'utf-8')
		self.post_values = unquote(post_values.replace('+',' '))
		self.query_string = unquote(query_string.replace('+',' '))
		self.cookies = unquote(cookies.replace('+',' '))
		
	# Probe function
	@staticmethod
	def _probe_value(data,varname):
		rx = re.compile('%s=([^&]+)' % varname)
		for match in rx.finditer(data):
			return match.group(1)
		return None
	
	def get_post_value(self,varname):
		return HTTPRequestData._probe_value(self.post_values,varname)
	
	def get_qs_value(self,varname):
		return HTTPRequestData._probe_value(self.query_string,varname)
	
	def get_cookie_value(self,varname):
		return HTTPRequestData._probe_value(self.cookies,varname)

	def get_any_value(self,varname):
		val = self.get_post_value(varname)
		if not val:
			val = self.get_qs_value(varname)
		if not val:
			val = self.get_cookie_value(varname)
		return val



# -*- coding: utf-8 -*-
from jinja2 import Template
from os.path import dirname,normpath,join,exists,abspath
import re,cgi,sys,imp,os,gzip,tempfile
from time import gmtime,strftime
from wsgiref.util import request_uri
from pysite.tools.log import logger,get_traceback
from pysite.tools.httptools import HTTPRequestData
from pysite.localization import localization
from pysite.conf import getConfiguration
from pysite.compat import PORTABLE_STRING, PORTABLE_BYTES
import types
import pysite.wsgi.httpheader

if sys.version_info[0]==2:
	from StringIO import StringIO
	from urlparse import parse_qs, urlparse
elif sys.version_info[0]>=3:
	from urllib.parse import parse_qs, urlparse
	from io import StringIO

#Last-Modified: Thu, 13 Dec 2012 13:13:59 GMT
#Accept-Ranges: bytes
#Vary: Accept-Encoding
#Content-Encoding: gzip
#Content-Length: 2106
#Content-Type: application/javascript


#Last-Modified: Thu, 13 Dec 2012 13:13:57 GMT
#Accept-Ranges: bytes
#Vary: Accept-Encoding
#Content-Encoding: gzip
#Content-Length: 263
#Content-Type: text/css


#Last-Modified: Thu, 13 Dec 2012 13:13:57 GMT
#Accept-Ranges: bytes
#Content-Length: 1722
#Content-Type: image/png



ext_map_content_type = {
	'js': {
		'Content-Type': 'application/javascript',
		'Content-Encoding': 'gzip'
	},
	'html': {
		'Content-Type': 'text/html',
		'Content-Encoding': 'gzip'
	},
	'css': {
		'Content-Type': 'text/css',
		'Content-Encoding': 'gzip'
	},
	'svg': {
		'Content-Type': 'image/svg+xml',
		'Content-Encoding': 'gzip'
	},
	'png': {
		'Content-Type': 'image/png'
	},
	'gif': {
		'Content-Type': 'image/gif'
	},
	'jpg': {
		'Content-Type': 'image/jpeg'
	},
	'bmp': {
		'Content-Type': 'image/bmp'
	},
	'ico': {
		'Content-Type': 'image/x-icon'
	},
	'woff': {
		'Content-Type': 'application/octet-stream'
	},
	'ttf': {
		'Content-Type': 'application/octet-stream'
	},
	'eot': {
		'Content-Type': 'application/octet-stream'
	}

}

def redirect(location,cookies,start_response):
	response_headers = [
		('Content-type', 'text/html; charset=utf-8'),
		('Location',location),
		('Content-Length','0')]
	for c in cookies:
		response_headers += [('Set-Cookie', c)]
	start_response('302 Redirect', response_headers)
	return ['']

	
class PySiteApplication(object):

	def __init__(self,basedir):
		self.basedir = abspath(basedir)
		self.conf = getConfiguration(basedir)
		self.templates_dir = join(basedir,'templates')
		self.subhandlers_dir = join(basedir,'subhandlers')
		self.translations_dir = join(basedir,'translations')
		sys.path.append(basedir)
		self.rx_static_file = re.compile('.+\.(%s)$' % '|'.join(ext_map_content_type.keys()),re.I)
	
	def __call__(self,environ, start_response):
		try:
			log = logger(self.conf)
			status = "200 OK"
			output = ""
			
			content_len = environ.get('CONTENT_LENGTH')
			post_data = ''
			if content_len:
				post_data = environ['wsgi.input'].read(int(content_len))
			query_string = environ['QUERY_STRING']
			cookies = ''
			if 'HTTP_COOKIE' in environ:
				cookies = environ['HTTP_COOKIE']
			req_data = HTTPRequestData(post_data,query_string,cookies)
			
			path = environ['PATH_INFO'][1:]
			# Static files
			m = self.rx_static_file.match(path)
			if m:
				ext = m.groups()[0].lower()
				if exists(join(self.basedir,path)):
					fpath = join(self.basedir,path)
					log.warning(fpath)
					fstat = os.stat(fpath)
					content_size = str(fstat.st_size)
					ftypeinfo = ext_map_content_type[ext]
					response_headers = [
						('Last-Modified',strftime("%a, %d %b %Y %H:%M:%S GMT",gmtime(fstat.st_mtime))),
						('Accept-Ranges', 'bytes'),
						('Content-Type', ftypeinfo['Content-Type']) ]
					tf = None
					if 'Content-Encoding' in ftypeinfo:
						response_headers += [('Content-Encoding',ftypeinfo['Content-Encoding'])]
						tf = tempfile.mktemp()
						zf = gzip.open(tf,'wb')
						ff = open(fpath,'rb')
						data = ff.read(4096)
						while data:
							zf.write(data)
							data = ff.read(4096)
						ff.close()
						zf.close()
						fpath = tf
						content_size = str(os.stat(tf).st_size)
					response_headers += [('Content-Length',content_size)]
					start_response(status, response_headers)
					f = open(fpath,'rb')
					data = f.read(4096)
					while data:
						yield data
						data = f.read(4096)
					if tf:
						os.unlink(fpath)
					raise StopIteration
				else:
					status = "404 Not Found"
					data = b'<h1>404 Not Found</h1>'
					response_headers = [
						('Content-Type', 'text/html; charset=UTF-8'),
						('Content-Length', str(len(data)) )]
					start_response(status, response_headers)
					yield data
					raise StopIteration

			locales = localization(self.translations_dir)
			ls = locales.lang_support()
			lang = None # Default
			default_lang = 'en'
			browser_langs = []
			if 'HTTP_ACCEPT_LANGUAGE' in environ:
				browser_langs = httpheader.parse_accept_language_header(environ['HTTP_ACCEPT_LANGUAGE'])
			for l in browser_langs:
				if lang:
					break
				for lp in l[0].parts:
					if lp in ls:
						lang = lp
						break
			if not lang:
				lang = default_lang
			
			template = environ['PATH_INFO'][1:]
			if template=='':
				template = 'main'
			template_info = {
				'tr':{},
				'tr_common':{},
				'sitename': self.conf.sitename,
				'sitetitle': self.conf.sitetitle
			}
			template_info['supported_countries'] = [
				{'short': 'dk', 'title': PORTABLE_STRING('Danmark')},
				{'short': 'se', 'title': PORTABLE_STRING('Sverige')},
				{'short': 'no', 'title': PORTABLE_STRING('Norge')}
			]
			template_info.update(locales.tr(lang,'common',disambiguation='school'))
			template_info.update(locales.tr(lang,template,disambiguation='school'))
			template_info['tr_common'].update(locales.tr(lang,'common',disambiguation='school'))
			template_info['tr'].update(locales.tr(lang,template,disambiguation='school'))
			
			# Request translator
			def translate(source,context=template,comment=None,lang=lang,locales=locales):
				return locales.tr(lang,context=context,source=source,disambiguation=comment)

			subhandler = None
			subhandler_py = join(self.basedir,'subhandlers','%s.py' % template)
			if exists(subhandler_py):
				subhandler = imp.load_source('subhandlers.%s' % template, subhandler_py)
			
			response_headers = []

			environ['lang_support'] = locales.lang_support
			environ['tr'] = locales.tr
			environ['logger'] = log
			environ['lang'] = lang
			init = getattr(subhandler,'init',None)
			if init:
				try:
					res = init(template_info,response_headers,environ,translate,req_data)
					if type(res)==types.GeneratorType:
						first_iter = True
						template_off = False
						for data in res:
							if first_iter:
								template_off = template_info.get("template_off",False)
								if template_off:
									start_response(status, response_headers)
								first_iter = False
							if template_off:
								yield data
						if template_off:
							raise StopIteration
					elif type(res)==str:
						template_off = template_info.get("template_off",False)
						if template_off:
							start_response(status, response_headers)
							yield res
							raise StopIteration
				except Exception as e:
					log.warning(get_traceback())
					raise e
			
			subhandler_redirect = getattr(subhandler,'redirect',None)
			if subhandler_redirect:
				cookies = []
				location = subhandler_redirect(template_info,cookies,environ)
				if location:
					output = redirect(location,cookies,start_response)
					raise StopIteration
			
			template_info['translate'] = translate
			template = join(self.templates_dir,'%s.jinja' % template)
			if exists(template):
				jinja_temp = Template(PORTABLE_STRING(open(template,'rb').read(),'utf-8'))
				output = jinja_temp.render(template_info).encode('utf-8')
			else:
				output = b'Template: "%s" does not exist' % template if type(template)==PORTABLE_BYTES else template.encode('utf-8')
		except Exception as e:
			if type(e)==StopIteration:
				raise e
			log.warning(get_traceback())
			output = b'<h1>501 Internal Server Error</h1>'
			status = '501 Internal Server Error'
			response_headers = []
		
		response_headers += [
			('Content-type', 'text/html; charset=utf-8'),
			('Content-Length', str(len(output)))]
		
		start_response(status, response_headers)
		yield output




#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import sys,os,shutil

if sys.version_info.major==2:
	other_version = 3
else:
	other_version = 2

pysite_command = 'pysite-%d.%d' % (sys.version_info.major,sys.version_info.minor)

readme = changes = ''
if os.path.exists('README.rst'):
	readme = open('README.rst').read()
if os.path.exists('CHANGES.rst'):
	changes = open('CHANGES.rst').read()

install_dir = os.path.dirname(os.path.abspath(__file__))
scripts_dir = os.path.join(install_dir,'scripts')
shutil.rmtree(scripts_dir,ignore_errors=True)
if not os.path.exists(scripts_dir):
	os.makedirs(scripts_dir)
f_pysite_temp = open(os.path.join(install_dir,'script','templates','pysite'))
f_pysite_cmd = open(os.path.join(scripts_dir,pysite_command),'w')
f_pysite_cmd.write(f_pysite_temp.read().replace('<INTERPRETER>',sys.executable))
f_pysite_cmd.close()
f_pysite_temp.close()

VERSION = '0.2.1'

SHORT_DESC = "Create simple yet powerful WSGI based sites, utilizing Jinja2 and Qt's TS-file format for localization"

def walk_dir(dirname):
	files = []
	def detect_svn(fname):
		return fname.find('.svn')==-1
	for f in filter(detect_svn ,map(lambda fname: os.path.join(dirname,fname),os.listdir(dirname))):
		files += [f]
	return files

def packages(basedir):
	p = []
	for base,dirs,files in os.walk(basedir):
		if base.find('.svn')==-1:
			p+=['.'.join(base.split(os.path.sep)[1:])]
	return p

data_files= [
	('script/templates',walk_dir('script/templates')),
	('resources/init/static/css',walk_dir('resources/init/static/css')),
	('resources/init/static/images',walk_dir('resources/init/static/images')),
	('resources/init/templates',walk_dir('resources/init/templates'))]

print(data_files)
setup(
	name='pysite',
	packages=packages('src/pysite'),
	package_dir={'':'src'},
	version=VERSION,
	description=SHORT_DESC,
	long_description='\n\n'.join([readme, changes]),
	classifiers=[
		'Programming Language :: Python',
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 3',
		'Operating System :: OS Independent',
		'Natural Language :: English',
		'Intended Audience :: Developers',
		'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',       
	],
	keywords= ['wsgi', 'website', 'www', 'website', 'framework'],
	author='Jakob Simon-Gaarde',
	author_email='jakob@simon-gaarde.dk',
	maintainer = 'Jakob Simon-Gaarde',
	maintainer_email = 'jakob@simon-gaarde.dk',
	install_requires=['jinja2'],
	requires=['jinja2'],
	provides=['pysite'],
	license='LGPL3',
	scripts=['scripts/%s' % pysite_command],
	data_files= data_files,
	zip_safe=False
)



from pysite.exceptions import PySiteException

class ConfException(PySiteException):
	def __init__(self,details):
		super(ConfException,self).__init__()
		self.details = details
	
	def __str__(self):
		return self.details
